Only in /usr/src/usr.sbin/jail: CVS
diff -u /usr/src/usr.sbin/jail/jail.c usr.sbin/jail/jail.c
--- /usr/src/usr.sbin/jail/jail.c	Tue Aug  1 13:50:48 2006
+++ usr.sbin/jail/jail.c	Tue Aug  1 12:18:07 2006
@@ -56,6 +56,7 @@
 	struct in_addr in;
 	gid_t groups[NGROUPS];
 	int ch, i, iflag, Jflag, lflag, ngroups, securelevel, uflag, Uflag;
+	unsigned int mem_limit, priority;
 	char path[PATH_MAX], *ep, *username, *JidFile;
 	static char *cleanenv;
 	const char *shell, *p = NULL;
@@ -63,11 +64,13 @@
 	FILE *fp;
 
 	iflag = Jflag = lflag = uflag = Uflag = 0;
+	mem_limit = JAIL_DEFAULT_MEM_LIMIT;
+	priority = JAIL_DEFAULT_PRIORITY;
 	securelevel = -1;
 	username = JidFile = cleanenv = NULL;
 	fp = NULL;
 
-	while ((ch = getopt(argc, argv, "ils:u:U:J:")) != -1) {
+	while ((ch = getopt(argc, argv, "ilp:m:s:u:U:J:")) != -1) {
 		switch (ch) {
 		case 'i':
 			iflag = 1;
@@ -76,6 +79,17 @@
 			JidFile = optarg;
 			Jflag = 1;
 			break;
+		case 'm':
+			/* TODO --- should this be specified in MB? */
+			mem_limit = atoi(optarg);
+			mem_limit *= 1024 * 1024;
+			break;
+		case 'p':
+			priority = atoi(optarg);
+			if (priority < JAIL_MINIMUM_PRIORITY || 
+                            priority > JAIL_MAXIMUM_PRIORITY)
+				errx(1, "invalid priority: `%s'", optarg);
+			break;
 		case 's':
 			ltmp = strtol(optarg, &ep, 0);
 			if (*ep || ep == optarg || ltmp > INT_MAX || !ltmp)
@@ -118,6 +132,8 @@
 	if (inet_aton(argv[2], &in) == 0)
 		errx(1, "Could not make sense of ip-number: %s", argv[2]);
 	j.ip_number = ntohl(in.s_addr);
+	j.mem_limit = mem_limit;
+	j.priority = priority;
 	if (Jflag) {
 		fp = fopen(JidFile, "w");
 		if (fp == NULL)
@@ -182,8 +198,10 @@
 usage(void)
 {
 
-	(void)fprintf(stderr, "%s%s%s\n",
-	     "usage: jail [-i] [-J jid_file] [-s securelevel] [-l -u ",
+	(void)fprintf(stderr, "%s%s%s%s%s\n",
+	     "usage: jail [-i] [-J jid_file] [-m mem_limit] ",
+             "[-p priority] [-s securelevel]",
+             " [-l -u ",
 	     "username | -U username]",
 	     " path hostname ip-number command ...");
 	exit(1);
